@@ -36,11 +36,6 @@
 #include "trash-empty.h"
 #include "xstuff.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 typedef MatePanelAppletClass TrashAppletClass;
 
 typedef struct
@@ -171,6 +166,9 @@ trash_applet_size_allocate (GtkWidget    *widget,
 {
   TrashApplet *applet = TRASH_APPLET (widget);
 
+  GTK_WIDGET_CLASS (trash_applet_parent_class)
+    ->size_allocate (widget, allocation);
+
   switch (mate_panel_applet_get_orient (MATE_PANEL_APPLET (applet)))
   {
     case MATE_PANEL_APPLET_ORIENT_LEFT:
@@ -184,8 +182,6 @@ trash_applet_size_allocate (GtkWidget    *widget,
       break;
   }
 
-  GTK_WIDGET_CLASS (trash_applet_parent_class)
-    ->size_allocate (widget, allocation);
 }
 
 static void
@@ -469,7 +465,7 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 14);
 
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   gtk_widget_show (hbox);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox,
@@ -477,16 +473,12 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION,
                                     GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
   gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (image, GTK_ALIGN_START);
-#else
-  gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-#endif
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 12);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
